aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-artnet.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-artnet.c')
-rw-r--r--epan/dissectors/packet-artnet.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-artnet.c b/epan/dissectors/packet-artnet.c
index 8adb921b86..c6f3684bd8 100644
--- a/epan/dissectors/packet-artnet.c
+++ b/epan/dissectors/packet-artnet.c
@@ -3135,12 +3135,12 @@ dissect_artnet_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
guint64 qword;
/* check if we atleast have the 8 byte header */
- if (tvb_length(tvb) < 8)
+ if (tvb_captured_length(tvb) < 8)
return FALSE;
/* Check the 8 byte header "Art-Net\0" = 0x4172742d4e7400*/
qword = tvb_get_ntoh64(tvb,0);
- if(qword != G_GUINT64_CONSTANT (0x4172742d4e7400))
+ if(qword != G_GUINT64_CONSTANT (0x4172742d4e657400))
return FALSE;
/* if the header matches, dissect it */
@@ -3135,12 +3135,12 @@ dissect_artnet_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
return FALSE;
- /* Check the 8 byte header "Art-Net\0" = 0x4172742d4e7400*/
+ /* Check the 8 byte header "Art-Net\0" = 0x4172742d4e657400*/
qword = tvb_get_ntoh64(tvb,0);